==> Project Epsilon 1.0.0.4.zip: Project Epsilon 1.0.0.4/Resources/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by Resource.rc
//
#define IDS_TITLECAPTION                1
#define IDS_FILEVERSION                 2
#define IDS_APPCOPYRIGHT                3
#define IDD_NEWPASS                     100
#define IDI_MAIN                        101
#define IDI_MAINICON                    101
#define IDD_MAIN                        102
#define IDD_OPENPASS                    103
#define IDI_SFOLDER                     103
#define IDD_READING                     104
#define IDI_FOLDER                      104
#define IDD_PACKING                     105
#define IDI_HELP                        105
#define IDI_SFILE                       107
#define IDI_FILE                        108
#define IDC_HANDCURSOR                  110
#define IDI_APPICON                     111
#define IDI_UNKNOWN                     112
#define IDB_WIZARD                      113
#define IDB_CHECKOUT                    114
#define IDB_CLOSE                       115
#define IDB_DELETE                      116
#define IDB_EMAIL                       117
#define IDB_EXIT                        118
#define IDB_EXTRACT                     119
#define IDB_HELP                        120
#define IDB_HISTORY                     121
#define IDB_NEW                         122
#define IDB_NOTES                       123
#define IDB_OPEN                        124
#define IDB_OPTIONS                     125
#define IDB_PRINT                       126
#define IDB_PROPERTIES                  127
#define IDB_UUECODE                     128
#define IDB_VIEWFILE                    129
#define IDB_ADDFILES                    130
#define IDB_TOOLBAR                     131
#define IDR_MAINMENU                    132
#define IDR_DECRYPTAVI                  135
#define IDR_ENCRYPTAVI                  136
#define IDD_EXTRACT                     137
#define IDB_BITMAP1                     141
#define IDB_TREE_REMOVABLE              141
#define IDB_BITMAP2                     142
#define IDB_TREE_CLOSEDFOLDER           142
#define IDB_BITMAP3                     143
#define IDB_TREE_DESKTOP                143
#define IDB_BITMAP4                     144
#define IDB_TREE_FIXED                  144
#define IDB_BITMAP5                     145
#define IDB_TREE_MYCOMPUTER             145
#define IDB_BITMAP6                     146
#define IDB_TREE_MYDOCS                 146
#define IDB_BITMAP7                     147
#define IDB_TREE_NETWORK                147
#define IDB_BITMAP8                     148
#define IDB_TREE_OPENFOLDER             148
#define IDB_BITMAP9                     149
#define IDB_TREE_CDROM                  149
#define IDB_TREE_UNKNOWN                150
#define IDB_TREE_RAMDRIVE               151
#define IDR_SCANDIRAVI                  153
#define IDC_PASSWORD1                   1000
#define IDC_TEXTBOX                     1000
#define IDC_OK                          1001
#define IDC_CANCEL                      1002
#define IDC_STATICTEXT                  1003
#define IDC_STATUSTEXT                  1003
#define IDC_CMDHELP                     1003
#define IDC_NEWFOLDER                   1004
#define IDC_FILELIST                    1005
#define IDC_LIST2                       1005
#define IDC_PASSWORD                    1006
#define IDC_PROGRESS                    1008
#define IDC_MULBUTTON                   1010
#define IDC_ALWAYSONTOP                 1012
#define IDC_EXTRACT                     1013
#define IDC_AVIFRAME                    1014
#define IDC_EDIT1                       1015
#define IDC_EXTRACTLOCATION             1015
#define IDC_BROWSE                      1016
#define IDC_SELECTEDRADIO               1017
#define IDC_ALLRADIO                    1018
#define IDC_CHECK1                      1019
#define IDC_OVERWRITE                   1019
#define IDC_CHECK2                      1020
#define IDC_SKIPOLDER                   1020
#define IDC_CHECK3                      1021
#define IDC_USEFOLDERS                  1021
#define IDC_BROWSETREE                  1023
#define IDC_GOTO                        1024
#define IDC_PASSWORD2                   2000
#define IDC_PASSWORDBAR1                2000
#define IDC_PASSWORDBAR2                3000
#define IDC_PASSWORDBITS1               3000
#define IDC_PASSWORDBITS2               4000
#define ID_FILE_EXIT                    40001

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        154
#define _APS_NEXT_COMMAND_VALUE         40004
#define _APS_NEXT_CONTROL_VALUE         1025
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> Project Epsilon 1.0.2.0.zip: Project Epsilon 1.0.2.0/Resources/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by Resource.rc
//
#define IDS_TITLECAPTION                1
#define IDS_FILEVERSION                 2
#define IDS_APPCOPYRIGHT                3
#define IDD_NEWPASS                     100
#define IDI_MAIN                        101
#define IDI_MAINICON                    101
#define IDD_MAIN                        102
#define IDD_OPENPASS                    103
#define IDI_SFOLDER                     103
#define IDD_READING                     104
#define IDI_FOLDER                      104
#define IDD_PACKING                     105
#define IDI_HELP                        105
#define IDI_SFILE                       107
#define IDI_FILE                        108
#define IDC_HANDCURSOR                  110
#define IDI_APPICON                     111
#define IDI_UNKNOWN                     112
#define IDB_WIZARD                      113
#define IDB_CHECKOUT                    114
#define IDB_CLOSE                       115
#define IDB_DELETE                      116
#define IDB_EMAIL                       117
#define IDB_EXIT                        118
#define IDB_EXTRACT                     119
#define IDB_HELP                        120
#define IDB_HISTORY                     121
#define IDB_NEW                         122
#define IDB_NOTES                       123
#define IDB_OPEN                        124
#define IDB_OPTIONS                     125
#define IDB_PRINT                       126
#define IDB_PROPERTIES                  127
#define IDB_UUECODE                     128
#define IDB_VIEWFILE                    129
#define IDB_ADDFILES                    130
#define IDB_TOOLBAR                     131
#define IDR_MAINMENU                    132
#define IDR_DECRYPTAVI                  135
#define IDR_ENCRYPTAVI                  136
#define IDD_EXTRACT                     137
#define IDD_NEWFOLDER                   138
#define IDB_BITMAP1                     141
#define IDB_TREE_REMOVABLE              141
#define IDB_BITMAP2                     142
#define IDB_TREE_CLOSEDFOLDER           142
#define IDB_BITMAP3                     143
#define IDB_TREE_DESKTOP                143
#define IDB_BITMAP4                     144
#define IDB_TREE_FIXED                  144
#define IDB_BITMAP5                     145
#define IDB_TREE_MYCOMPUTER             145
#define IDB_BITMAP6                     146
#define IDB_TREE_MYDOCS                 146
#define IDB_BITMAP7                     147
#define IDB_TREE_NETWORK                147
#define IDB_BITMAP8                     148
#define IDB_TREE_OPENFOLDER             148
#define IDB_BITMAP9                     149
#define IDB_TREE_CDROM                  149
#define IDB_TREE_UNKNOWN                150
#define IDB_TREE_RAMDRIVE               151
#define IDR_SCANDIRAVI                  153
#define IDR_CLICKWAVE                   154
#define IDR_TICKWAVE                    159
#define IDC_PASSWORD1                   1000
#define IDC_TEXTBOX                     1000
#define IDC_OK                          1001
#define IDC_CANCEL                      1002
#define IDC_STATICTEXT                  1003
#define IDC_STATUSTEXT                  1003
#define IDC_CMDHELP                     1003
#define IDC_NEWFOLDER                   1004
#define IDC_FILELIST                    1005
#define IDC_LIST2                       1005
#define IDC_PASSWORD                    1006
#define IDC_PROGRESS                    1008
#define IDC_MULBUTTON                   1010
#define IDC_ALWAYSONTOP                 1012
#define IDC_EXTRACT                     1013
#define IDC_DECRYPT                     1013
#define IDC_AVIFRAME                    1014
#define IDC_EDIT1                       1015
#define IDC_EXTRACTLOCATION             1015
#define IDC_SAVETOLOCATION              1015
#define IDC_FOLDERNAME                  1015
#define IDC_DECRYPTLOCATION             1015
#define IDC_BROWSE                      1016
#define IDC_SELECTEDRADIO               1017
#define IDC_ALLRADIO                    1018
#define IDC_CHECK1                      1019
#define IDC_OVERWRITE                   1019
#define IDC_ENABLECOMPRESSION           1019
#define IDC_CHKTIMESTAMPS               1019
#define IDC_CHECK2                      1020
#define IDC_SKIPOLDER                   1020
#define IDC_CHKATTRIBUTES               1020
#define IDC_CHECK3                      1021
#define IDC_USEFOLDERS                  1021
#define IDC_CHKCRCS                     1021
#define IDC_CHKSAVEPATHS                1022
#define IDC_BROWSETREE                  1023
#define IDC_GOTO                        1024
#define IDC_COMBO1                      1025
#define IDC_COMPRESSLEVEL               1025
#define IDC_TREE1                       1026
#define IDC_ENCRYPTALGO                 1026
#define IDC_EDIT2                       1027
#define IDC_SAVETOFILE                  1027
#define IDC_ACTION                      1028
#define IDC_ENCRYPT                     1029
#define IDC_PASSWORD2                   2000
#define IDC_PASSWORDBAR1                2000
#define IDC_PASSWORDBAR2                3000
#define IDC_PASSWORDBITS1               3000
#define IDC_PASSWORDBITS2               4000
#define ID_FILE_EXIT                    40001

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        160
#define _APS_NEXT_COMMAND_VALUE         40005
#define _APS_NEXT_CONTROL_VALUE         1030
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
